@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1996-2021, OFFIS e.V.
+ *  Copyright (C) 1996-2024, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -969,43 +969,7 @@ void WlmActivityManager::CleanChildren()
       RemoveProcessFromTable( child );
     }
   }
-
-#elif defined(HAVE_WAIT3)                                     // PLATFORMS THAT HAVE wait3()
-#if defined(__NeXT__)
-  // some systems need a union wait as argument to wait3
-  union wait status;
 #else
-  int status;
-#endif
-  int options = WNOHANG;
-  struct rusage rusage;
-  int child = 1;
-
-  while( child > 0 )
-  {
-    // determine status for child processes
-    child = wait3( &status, options, &rusage );
-    if( child < 0 )
-    {
-      if( errno == ECHILD )
-      {
-        // no children
-      }
-      else
-      {
-        DCMWLM_WARN("WlmActivityManager::CleanChildren: Wait for child failed");
-      }
-    }
-    else if( child > 0 )
-    {
-      // dump some information if required
-      DCMWLM_INFO("Cleaned up after child (" << child << ")");
-
-      // remove item from process table
-      RemoveProcessFromTable( child );
-    }
-  }
-#else                                                         // OTHER PLATFORMS
 // for other platforms without waitpid() and without wait3() we
 // don't know how to cleanup after children. Dump an error message.
   DCMWLM_WARN("WlmActivityManager::CleanChildren: Cannot wait for child processes");
